==> namebase-0.0.2.tar.gz: lib/src/models/record.dart <==
import 'dart:typed_data';

const FINGERPRINT_DIVIDER = "v=0;fingerprint=";
const AUTH_DIVIDER = "._auth.";

class HSRecord {
  HSRecord({
    required this.ttl,
    required this.type,
    required this.host,
    required this.value,
  });

  int ttl;
  String type;
  String host;
  String value;

  bool get isAuth => this.host.contains(AUTH_DIVIDER);
  bool get isName => !this.isAuth && !this.isBlank && !this.host.contains("_") && this.type.toLowerCase().contains("txt");
  bool get isBlank => this.ttl == -1 && this.type == "-" && this.host == "-" && this.value == "-";
  bool get isNotBlank => !this.isBlank;
  Uint8List get fingerprint => isAuth ? extractFingerprint(value) : Uint8List(0);

  String get prefix => isAuth ? extractPrefix(host) : "";
  String get publicKey => isName ? this.value : "";

  String get name {
    if (isAuth) {
      return extractName(host);
    } else if (isName) {
      return host;
    }
    return "";
  }

  // Method Checks if Prefix Values are the same
  bool equals(String n, String p) => isAuth ? this.equalsName(n) && this.equalsPrefix(p) : false;
  bool equalsName(String n) => this.name.toLowerCase() == n.toLowerCase();
  bool equalsPrefix(String p) => this.prefix == p;
  bool notEquals(String n, String p) => this.notEqualsName(n) && this.notEqualsPrefix(p);
  bool notEqualsName(String n) => this.name.toLowerCase() != n.toLowerCase();
  bool notEqualsPrefix(String p) => this.prefix != p;

  /// Returns Blank Record
  factory HSRecord.blank() {
    return HSRecord(ttl: -1, type: "-", host: "-", value: "-");
  }

  /// Creates Record From JSON
  factory HSRecord.fromJson(dynamic json) => HSRecord(
        ttl: json["ttl"],
        type: json["type"],
        host: json["host"],
        value: json["value"],
      );

  /// Creates New `Auth` Record from AuthResponse
  factory HSRecord.newAuth({required String prefix, required String name, required String fingerprint}) {
    return HSRecord(
      ttl: 5,
      type: "TXT",
      host: "$prefix$AUTH_DIVIDER$name",
      value: FINGERPRINT_DIVIDER + fingerprint,
    );
  }

  /// Creates New `Name` Record from AuthResponse
  factory HSRecord.newName({required String publicKey, required String name}) {
    return HSRecord(
      ttl: 5,
      type: "TXT",
      host: name,
      value: publicKey,
    );
  }

  /// Returns Auth/Name Record from AuthResponse
  /// [0] - AuthRecord
  /// [1] - NameRecord
  static List<HSRecord> newRegisteredRecords({
    required String prefix,
    required String name,
    required String fingerprint,
    required String publicKey,
  }) =>
      [
        HSRecord.newAuth(prefix: prefix, name: name, fingerprint: fingerprint),
        HSRecord.newName(publicKey: publicKey, name: name),
      ];

  // Extracts FingerPrint from Record Value
  static Uint8List extractFingerprint(String value) {
    var data = value.substring(FINGERPRINT_DIVIDER.length);
    return Uint8List.fromList(data.codeUnits);
  }

  // Extracts Prefix from Record Host
  static String extractPrefix(String host) {
    var idx = host.indexOf(AUTH_DIVIDER);
    return host.substring(0, idx);
  }

  // Extracts Name from Record Host
  static String extractName(String host) {
    var idx = host.indexOf(AUTH_DIVIDER);
    return host.substring(idx + AUTH_DIVIDER.length);
  }

  /// Converts Record to Map for REST API
  Map<String, dynamic> toMap() => {
        "ttl": ttl,
        "type": type,
        "host": host,
        "value": value,
      };

  @override
  String toString() {
    if (this.isAuth) {
      return "--Auth Record-- \n" +
          {
            "Fingerprint": this.fingerprint,
            "Prefix": this.prefix,
            "Name": this.name,
          }.toString();
    } else {
      return "--Default Record-- \n" + this.toMap().toString();
    }
  }
}

==> namebase-0.1.1.tar.gz: lib/src/models/record.dart <==
import 'dart:typed_data';

const FINGERPRINT_DIVIDER = "v=0;fingerprint=";
const AUTH_DIVIDER = "._auth.";

class DNSRecord {
  DNSRecord({
    required this.ttl,
    required this.type,
    required this.host,
    required this.value,
  });

  /// Record TTL (*Time to Live*) in Seconds
  int ttl;

  /// Record type (e.g. A, CNAME, MX, TXT, etc.)
  String type;

  /// Record hostname
  String host;

  /// Record value (e.g. publicKey, fingerprint, etc.)
  String value;

  /// Checks if this record is a `Auth` Type Record
  bool get isAuth => this.host.contains(AUTH_DIVIDER);

  /// Checks if this record is a `Name` Type Record
  bool get isName => !this.isAuth && !this.isBlank && !this.host.contains("_") && this.type.toLowerCase().contains("txt");

  /// Checks if this record is blank
  bool get isBlank => this.ttl == -1 && this.type == "-" && this.host == "-" && this.value == "-";

  /// Checks if this record is **NOT** blank
  bool get isNotBlank => !this.isBlank;

  /// Returns the fingerprint for this record.
  Uint8List get fingerprint => isAuth ? extractFingerprint(value) : Uint8List(0);

  /// Returns Prefix from this Record
  String get prefix => isAuth ? extractPrefix(host) : "";

  /// Returns Public Key from this Record
  String get publicKey => isName ? this.value : "";

  /// Returns Record SName by Record Type
  String get name {
    if (isAuth) {
      return extractName(host);
    } else if (isName) {
      return host;
    }
    return "";
  }

  /// Checks if this Record has a **VALID** `fingerprint`
  bool equals(String n, String p) => isAuth ? this.equalsName(n) && this.equalsPrefix(p) : false;

  /// Checks if this Record **EQUALS** given `name`
  bool equalsName(String n) => this.name.toLowerCase() == n.toLowerCase();

  /// Checks if this Record **EQUALS** equal given `prefix`
  bool equalsPrefix(String p) => this.prefix == p;

  /// Checks if this Record has a **INVALID** `fingerprint`
  bool notEquals(String n, String p) => this.notEqualsName(n) && this.notEqualsPrefix(p);

  /// Checks if this Record **DOES NOT** equal given `name`
  bool notEqualsName(String n) => this.name.toLowerCase() != n.toLowerCase();

  /// Checks if this Record **DOES NOT** equal given `prefix`
  bool notEqualsPrefix(String p) => this.prefix != p;

  /// Returns Blank Record
  factory DNSRecord.blank() {
    return DNSRecord(ttl: -1, type: "-", host: "-", value: "-");
  }

  /// Creates Record From JSON
  factory DNSRecord.fromJson(dynamic json) => DNSRecord(
        ttl: json["ttl"],
        type: json["type"],
        host: json["host"],
        value: json["value"],
      );

  /// Creates New `Auth` Record from AuthResponse
  factory DNSRecord.newAuth({required String prefix, required String name, required String fingerprint}) {
    return DNSRecord(
      ttl: 5,
      type: "TXT",
      host: "$prefix$AUTH_DIVIDER$name",
      value: FINGERPRINT_DIVIDER + fingerprint,
    );
  }

  /// Creates New `Name` Record from AuthResponse
  factory DNSRecord.newName({required String publicKey, required String name}) {
    return DNSRecord(
      ttl: 5,
      type: "TXT",
      host: name,
      value: publicKey,
    );
  }

  /// Returns Auth/Name Record from AuthResponse
  /// [0] - AuthRecord
  /// [1] - NameRecord
  static List<DNSRecord> newRegisteredRecords({
    required String prefix,
    required String name,
    required String fingerprint,
    required String publicKey,
  }) =>
      [
        DNSRecord.newAuth(prefix: prefix, name: name, fingerprint: fingerprint),
        DNSRecord.newName(publicKey: publicKey, name: name),
      ];

  /// Extracts FingerPrint from Record Value
  static Uint8List extractFingerprint(String value) {
    var data = value.substring(FINGERPRINT_DIVIDER.length);
    return Uint8List.fromList(data.codeUnits);
  }

  /// Extracts Prefix from Record Host
  static String extractPrefix(String host) {
    var idx = host.indexOf(AUTH_DIVIDER);
    return host.substring(0, idx);
  }

  /// Extracts Name from Record Host
  static String extractName(String host) {
    var idx = host.indexOf(AUTH_DIVIDER);
    return host.substring(idx + AUTH_DIVIDER.length);
  }

  /// Converts Record to Map for REST API
  Map<String, dynamic> toMap() => {
        "ttl": ttl,
        "type": type,
        "host": host,
        "value": value,
      };

  @override
  String toString() {
    if (this.isAuth) {
      return "--Auth Record-- \n" +
          {
            "Fingerprint": this.fingerprint,
            "Prefix": this.prefix,
            "Name": this.name,
          }.toString();
    } else {
      return "--Default Record-- \n" + this.toMap().toString();
    }
  }
}
